package com.vromtr.paad.ch8.googlemapstest;

import java.util.List;

import android.content.Context;
import android.location.Criteria;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Bundle;
import android.widget.TextView;

import com.google.android.maps.GeoPoint;
import com.google.android.maps.MapActivity;
import com.google.android.maps.MapController;
import com.google.android.maps.MapView;
import com.google.android.maps.MyLocationOverlay;
import com.google.android.maps.Overlay;


//Notice how this extends MAPACTIVITY instead of the base Activity class
public class MyMapActivity extends MapActivity {
    
	//MapView is the Google Maps control
	private MapView mapView;
	
	//I'm guessing this is a class for working with the MapView
	private MapController mapController;
	
	/** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        //Call base method
    	super.onCreate(savedInstanceState);
        
    	//"Inflate" our layout
    	setContentView(R.layout.main);
    	
    	//Get a handle to our MapView control; store it.
    	mapView = (MapView) findViewById(R.id.map_view);
    	
    	//Get the MapView's associated controller.
    	//Believe it or not, used for controlling the MapView
    	mapController = mapView.getController();
    	
    	//Set the zoom/display/visible controls of our MapView
    	mapView.setSatellite(true);		//False gets regular map tiles
    	mapView.setStreetView(true);
    	mapView.setBuiltInZoomControls(true);
    	mapView.displayZoomControls(true);
    	mapController.setZoom(17);
    	
    	//Set up GPS code
    	
    	//LocationManager is a class for talking with the GPS and other location hardware on the phone
    	LocationManager locationManager;
    	
    	//No idea what a context is.
    	//But, it gets us the name we need to use to ask for a handle to the LocationManager instance (there's a global one we need to talk to)
    	String context = Context.LOCATION_SERVICE;
    	locationManager = (LocationManager) getSystemService(context);
    	
    	//Phones have multiple "location providers" - GPS, cell triangulation, guess from WiFi hotspots, etc.
    	//Here we pick a location provider based on criteria we specify
    	Criteria criteria = new Criteria();
    	
    	criteria.setAccuracy(Criteria.ACCURACY_FINE);	//Pretty much means GPS.  "Fine" accuracy means stalker-approved proximity.
    	criteria.setAltitudeRequired(false);			//We don't need an altimiter
    	criteria.setBearingRequired(false);				//We don't really need to know which direction you're facing
    	criteria.setCostAllowed(true);					//Some cell companies charge for GPS use?!  Bastards.  They'll be roasting with popes and usurers.
    	criteria.setPowerRequirement(Criteria.NO_REQUIREMENT);	//All the examples had POWER_LOW, but I care more about it finding the GPS hardware than battery life
    	
    	//Summon forth a location provider that matches our requirements!  (And is on!)
    	String provider = locationManager.getBestProvider(criteria, true);
    	
    	//Get the last known location and update the UI.
    	//This is not guaranteed to be your current location, or to have even been set at all.
    	//We'll set up a location listener for that.
    	Location location = locationManager.getLastKnownLocation(provider);
    	
    	//Our own method - update the UI
    	updateWithNewLocation(location);
    	
    	LocationListener locationListener = new LocationListener()
    	{

			public void onLocationChanged(Location location) {
				updateWithNewLocation(location);
				
			}

			public void onProviderDisabled(String provider) {
				// TODO Auto-generated method stub
				
			}

			public void onProviderEnabled(String provider) {
				// TODO Auto-generated method stub
				
			}

			public void onStatusChanged(String provider, int status,
					Bundle extras) {
				// TODO Auto-generated method stub
				
			}
    		
    	};
    	
    	locationManager.requestLocationUpdates(provider, 2000, 2, locationListener);	//Request that we get told when we move.
    	
    	//Overlays are graphical layers drawn over the map control
    	//Add the built-in "You Are Here" overlay that puts a dot at your current location
    	List<Overlay> overlays = mapView.getOverlays();
    	MyLocationOverlay myLocationOverlay = new MyLocationOverlay(this, mapView);
    	overlays.add(myLocationOverlay);
    	
    	//Turn on the compass and the You Are Here dot
    	myLocationOverlay.enableCompass();
    	myLocationOverlay.enableMyLocation();
    }
    
    private void updateWithNewLocation(Location location) {
		
		//We will fill this in with the latitude/longitude from "location"
		String latLongString;
		
		//Reference to our TextView (the only real component of our UI)
		TextView myLocationText;
		
		//Get a handle to our textview
		myLocationText = (TextView)findViewById(R.id.myLocationText);
		
		//If we have a location, build the string
		if (location != null)
		{
			double lat = location.getLatitude();
			double lng = location.getLongitude();
			latLongString = "Lat: " + lat + "\nLong: " + lng;
			
			//Google's MapView uses GeoPoints, which are dimensioned in some ridiculous fraction of a degree
			GeoPoint point = new GeoPoint((int)(lat * 1E6), (int)(lng * 1E6));
			
			//Set focus to our current location
			mapController.animateTo(point);
			
		
		}
		else
		{
			latLongString = "No location found.";
		}
		
		myLocationText.setText("Your current position is totally around: \n"+latLongString);
		
		
		
		
	}
    
    @Override
    protected boolean isRouteDisplayed()
    {
    	//Returns true if we're displaying driving directions
    	//Must override and return false
    	return false;
    }
}